@@ -105,7 +105,7 @@ def fix_user_hubl_workaround_493(sender, instance, **kwargs):
 
 @receiver(pre_save, sender=Circle)
 def set_jabberid(sender, instance, **kwargs):
-    if settings.JABBER_DEFAULT_HOST and not instance.jabberID:
+    if getattr(settings, 'JABBER_DEFAULT_HOST', False) and not instance.jabberID:
         instance.jabberID = '{}@conference.{}'.format(
             ''.join(
                 [
