@@ -31,16 +31,15 @@ class CirclePermissions(LDPPermissions):
 
         return perms
 
-    def get_container_permissions(self, request, view, obj=None):
-        perms = super().get_container_permissions(request, view, obj)
+    def get_container_permissions(self, request, view, obj=None, bypass=False):
+        if obj is None:
+            perms = super().get_container_permissions(request, view, obj)
 
-        if not request.user.is_anonymous:
-            default_perms = getattr(settings, 'USER_AUTHENTICATED_CIRCLE_PERMISSIONS', ['view', 'add'])
-            perms = perms.union(set(default_perms))
-
-            # a superuser can always add new circles
-            if request.user.is_superuser:
-                perms = perms.union({'add'})
+            if not request.user.is_anonymous and not bypass:
+                default_perms = getattr(settings, 'USER_AUTHENTICATED_CIRCLE_PERMISSIONS', ['view', 'add'])
+                perms = perms.union(set(default_perms))
+        else:
+            return self.get_object_permissions(request, view, obj)
 
         return perms
     
